#!/usr/bin/env python3
# coding: utf-8
# -*- coding: utf-8 -*-

import requests
import pprint
from src.logs import Logger
from src.notifications import Notifications
from src.settings import Settings


class OVHTracker:
    def __init__(self, config):
        self.settings = Settings().get(config)
        self.logger = Logger(
            self.settings["log"]["level"], self.settings["log"]["path"]
        )
        self.logger.info("App loaded")
        self.main()

    def main(self):
        self.getStock()
        self.findServer()

    def getStock(self):
        url = self.settings["main"]["api_url"]
        self.logger.info("Getting {}".format(url))
        try:
            resp = requests.get(url)
        except requests.exceptions.RequestException as e:
            raise SystemExit(e)
        if resp.json is not None:
            self.stock = resp.json()

    def findServer(self):
        for server in self.stock:
            for wantedServer in self.settings["main"]["id_server"]:
                if wantedServer in server["hardware"]:
                    for dc in server["datacenters"]:
                        for wantedDatacenter in self.settings["main"]["datacenter"]:
                            if wantedDatacenter in dc["datacenter"]:
                                if dc["availability"] not in ("unavailable", "unknown"):
                                    self.logger.info(
                                        "{} is available in {}".format(
                                            wantedServer, wantedDatacenter
                                        )
                                    )
                                    self.notify(wantedServer)

    def notify(self, server):
        self.notification = Notifications(self.settings)
        return True
